

set -ex



test -L $PREFIX/lib/libcusparse.so
test -f $PREFIX/lib/pkgconfig/cusparse*.pc
test -f $PREFIX/targets/sbsa-linux/include/cusparse.h
test -L $PREFIX/targets/sbsa-linux/lib/libcusparse.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libcusparse.so
exit 0
